<?php
/**
 * Setup autoloading for the tests.
 *
 * @category Horde
 * @package  Notification
 * @author   Gunnar Wrobel <wrobel@pardus.de>
 * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
 * @link     http://pear.horde.org/index.php?package=Notification
 */

/** Needed for PEAR_Error. */
@require_once 'PEAR.php';
